function [out] = homodyne(pdata,nsize)
% HOMODYNE performs homodyne reconstruction
%    HOMODYNE(X,N) performs the homodyne reconstruction for 2D 
%    k-space data X such that the final image has size N.
%
%    Partial Fourier is in the first dimension, ordered from 
%    high k-space values to low k-space values.
%
% See also HOMODYNE3D.
%
% (c) Joseph Y Cheng (jycheng@mrsrl.stanford.edu) 2011.
%
    
% SVN info: 
%     Date:     $Date: 2012-02-09 01:19:57 -0800 (Thu, 09 Feb 2012) $
%     Revision: $Revision: 1068 $
%     Author:   $Author: jycheng $
%     Id:       $Id: homodyne.m 1068 2012-02-09 09:19:57Z jycheng $
    
    [nx,ny] = size(pdata);
    gen_w = nsize-nx;

    out = zeros(nsize,ny);
    lfkdata = zeros(size(out));
    hfkdata = zeros(size(out));

    pdataF = [pdata;zeros(gen_w,ny)];
    
    hl = repmat(homodyneLFilt(nsize,gen_w,4),[1 ny]);
    hh = flipdim(repmat(homodyneHFilt(nsize,gen_w,4),[1 ny]),1);

    lfim = ifftnc(pdataF.*hl);
    hfim = ifftnc(pdataF.*hh);
    
    out = (hfim.*conj(lfim)./abs(lfim));
    
    return;

function h = homodyneHFilt(n,n0,w)

    n1 = n-n0;
    h = zeros(n,1);
    trans = cos(linspace(pi/2,pi,w+1)).^2;

    int = n0-w/2:n0+w/2;
    h(int) = trans;
    int = n0+w/2:n1-w/2;
    h(int) = 1;
    int = n1-w/2:n1+w/2;
    h(int) = 1+trans;
    h(n1+w/2:end) = 2;
    
function h = homodyneLFilt(n,n0,w)
    h = zeros(n,1);
    n1 = n-n0;
    trans = cos(linspace(pi/2,pi,w+1)).^2;

    int = n0-w/2:n0+w/2;
    h(int) = trans;
    int = n0+w/2:n1-w/2;
    h(int) = 1;
    int = n1-w/2:n1+w/2;
    h(int) = 1-trans;
    h(n1+w/2:end) = 0;
