function out = homodyne3D(data,nx,flip)
% HOMODYNE3D performs homodyne recon for 3D imaging
%    HOMODYNE3D(DATA,NX,[FLIP]) returns the reconstructed image
%    as OUT. NX is the desired size. Optional argument FLIP 
%    performs the homodyne reconstruction assuming that the 
%    center of k-space is closer to the lower indeces of x 
%    otherwise the center of k-space is closer to the higher
%    indeces.
%
% See also HOMODYNE.
%
% (c) Joseph Y Cheng(jycheng@mrsrl.stanford.edu) 2011.
%
    
% SVN info: 
%     Date:     $Date: 2012-02-09 01:19:57 -0800 (Thu, 09 Feb 2012) $
%     Revision: $Revision: 1068 $
%     Author:   $Author: jycheng $
%     Id:       $Id: homodyne3D.m 1068 2012-02-09 09:19:57Z jycheng $
    
    
    if nargin < 3
        flip = 0;
    end
    nSlice = size(data,3);
    data_z = ifftc(data,3);
    
    if flip
        data_z = flipdim(data_z,1);
    end
    
    data_temp = []; out = [];
    for N=1:nSlice
        out(:,:,N) = homodyne(data_z(:,:,N),nx);
    end
    
    if flip
        out = flipdim(out,1);
    end